@@ -8,6 +8,8 @@ from sys import stderr
 from time import sleep as time_sleep
 from typing import Dict, List, Optional
 
+from contracts import contract
+
 try:
     import vlc  # noqa: F401
 except OSError:
@@ -55,7 +57,7 @@ class Sound:
     def from_dict(cls, json: dict) -> Sound:
         return Sound(
             message=json["message"],
-            sound_filename=json["sound_filename"],
+            sound_filename=get_real_sound_filename(json.get("sound_filename")),
         )
 
     def __eq__(self, other) -> bool:
@@ -80,6 +82,7 @@ class ClockTimer:
     def sorted_sounds(self) -> Dict[int, Sound]:
         return {sec: self.sounds[sec] for sec in sorted(self.sounds)}
 
+    @contract(count=">=0")
     def run_once(self, count: int) -> None:
         sounds = self.sorted_sounds
 
