@@ -1,27 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import shutil
-import sys
 from optparse import OptionParser
+from sys import exit, stderr
 
 from exclock import __VERSION__
 from exclock.mains.play_clock_main import main as play_clock_main
 from exclock.mains.show_list_main import main as show_list_main
 from exclock.mains.specified_time_main import main as specified_time_main
-
-# check whether there exists vlc command or not
-try:
-    import vlc  # noqa: F401
-except OSError:
-    print("vlc not found.", file=sys.stderr)
-    sys.exit(1)
-
-
-def execulatable_xmessage() -> None:
-    if not shutil.which("xmessage"):
-        print("xmessage not found.", file=sys.stderr)
-        sys.exit(1)
+from exclock.util import executable
 
 
 def get_option_parser():
@@ -62,9 +49,12 @@ def get_option_parser():
 
 
 def main() -> None:
-    execulatable_xmessage()
+    if not executable("xmessage") and not executable("terminal-notifier"):
+        print("both xmessage and terminal-notifier not found.", file=stderr)
+        exit(1)
 
     opt, args = get_option_parser().parse_args()
+    print("abc")
 
     if opt.show_list:
         show_list_main()
