@@ -1,16 +1,18 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import optparse
 from datetime import datetime
 from os import getenv
 from pathlib import Path
 from sys import exit, stderr
 from time import sleep as time_sleep
-from typing import Optional
+from typing import List, Optional
 
 import vlc
 
 from exclock.util import (
+    DEFAULT_RING_FILENAME,
     convert_specific_time_to_time_delta,
     get_real_sound_filename,
     get_specific_time_from_str,
@@ -38,7 +40,7 @@ def get_ring_filename(ring_sound_filename: Optional[str]) -> str:
     def _get_ring_filename() -> str:
         ring_filename_in_sys = getenv('EXCLOCK_RING_FILENAME')
         if ring_sound_filename is None and ring_filename_in_sys is None:
-            return "__warning.mp3"
+            return DEFAULT_RING_FILENAME
         elif ring_sound_filename is None:
             return str(ring_filename_in_sys)
         else:
@@ -47,7 +49,7 @@ def get_ring_filename(ring_sound_filename: Optional[str]) -> str:
     return get_real_sound_filename(_get_ring_filename())
 
 
-def main(opt, args) -> None:
+def main(opt: optparse.Values, args: List[str]) -> None:
     spend_sec = get_spend_sec(opt.time)
     if spend_sec is None:
         print("time format is illegal.", file=stderr)
